Learn R Programming

hmma (version 1.1.0)

rbn.hssm: Random emission from Bayesian network.

Description

rbn.hsmm returns a random sample from the Bayesian network in the given state for the given model.

Usage

# S3 method for hssm
rbn(state, model)

Arguments

state

The state of the model.

model

The model.

Value

A vector with the samples of each node in the Bayesian network.